﻿using System;
using System.Windows;
using System.Windows.Media;

using TestLibrary;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 애플리케이션
        /// </summary>
        private Application application;

        /// <summary>
        /// 윈도우
        /// </summary>
        private Window window;

        /// <summary>
        /// 초기 배경 브러시
        /// </summary>
        private SolidColorBrush initialBackgroundBrush;

        /// <summary>
        /// 초기 전경 브러시
        /// </summary>
        private SolidColorBrush initialForegroundBrush;

        /// <summary>
        /// 초기 폰트 패밀리
        /// </summary>
        private FontFamily initialFontFamily;

        /// <summary>
        /// 폰트 크기
        /// </summary>
        private double initialFontSize;

        /// <summary>
        /// 초기 폰트 스타일
        /// </summary>
        private FontStyle initialFontStyle;

        /// <summary>
        /// 초기 폰트 가중치
        /// </summary>
        private FontWeight initialFontWeight;

        /// <summary>
        /// 준비 여부
        /// </summary>
        private bool ready = false;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            Loaded                                           += Window_Loaded;
            this.originalBackgroundColorRadioButton.Click    += backgroundColorRadioButton_Click;
            this.lightGreenBackgroundColorRadioButton.Click  += backgroundColorRadioButton_Click;
            this.lightSalmonBackgroundColorRadioButton.Click += backgroundColorRadioButton_Click;
            this.originalForegroundColorRadioButton.Click    += foregroundColorRadioButton_Click;
            this.redForegroundColorRadioButton.Click         += foregroundColorRadioButton_Click;
            this.yellowForegroundColorReadioButton.Click     += foregroundColorRadioButton_Click;
            this.originalFontFamilyRadioButton.Click         += fontFamilyRadioButton_Click;
            this.timesNewRomanFontFamilyRadioButton.Click    += fontFamilyRadioButton_Click;
            this.wingdingsFontFamilyRadioButton.Click        += fontFamilyRadioButton_Click;
            this.originalFontSizeRadioButton.Click           += fontSizeRadioButton_Click;
            this.tenFontSizeRadioButton.Click                += fontSizeRadioButton_Click;
            this.twelveFontSizeRadioButton.Click             += fontSizeRadioButton_Click;
            this.normalFontStyleRadioButton.Click            += fontStyleRadioButton_Click;
            this.italicFontStyleRadioButton.Click            += fontStyleRadioButton_Click;
            this.originalFontWeightRadioButton.Click         += fontWeightRadioButton_Click;
            this.boldFontWeightRadioButton.Click             += fontWeightRadioButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, EventArgs e)
        {
            this.application = Application.Current;

            this.window = this.application.MainWindow;

            this.windowsFormsHost.TabIndex = 10;

            this.initialBackgroundBrush = (SolidColorBrush)this.windowsFormsHost.Background;
            this.initialForegroundBrush = (SolidColorBrush)this.windowsFormsHost.Foreground;
            this.initialFontFamily      = this.windowsFormsHost.FontFamily;
            this.initialFontSize        = this.windowsFormsHost.FontSize;
            this.initialFontStyle       = this.windowsFormsHost.FontStyle;
            this.initialFontWeight      = this.windowsFormsHost.FontWeight;

            CustomControl customControl = this.windowsFormsHost.Child as CustomControl;

            customControl.ButtonClick += customControl_ButtonClick;

            this.ready = true;
        }

        #endregion
        #region 배경색 라디오 버튼 클릭시 처리하기 - backgroundColorRadioButton_Click(sender, e)

        /// <summary>
        /// 배경색 라디오 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void backgroundColorRadioButton_Click(object sender, RoutedEventArgs e)
        {
            if(sender == this.lightGreenBackgroundColorRadioButton)
            {
                this.windowsFormsHost.Background = new SolidColorBrush(Colors.LightGreen);
            }
            else if(sender == this.lightSalmonBackgroundColorRadioButton)
            {
                this.windowsFormsHost.Background = new SolidColorBrush(Colors.LightSalmon);
            }
            else if(this.ready == true)
            {
                this.windowsFormsHost.Background = this.initialBackgroundBrush;
            }
        }

        #endregion
        #region 전경색 라디오 버튼 클릭시 처리하기 - foregroundColorRadioButton_Click(sender, e)

        /// <summary>
        /// 전경색 라디오 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void foregroundColorRadioButton_Click(object sender, RoutedEventArgs e)
        {
            if(sender == this.redForegroundColorRadioButton)
            {
                this.windowsFormsHost.Foreground = new SolidColorBrush(Colors.Red);
            }
            else if(sender == this.yellowForegroundColorReadioButton)
            {
                this.windowsFormsHost.Foreground = new SolidColorBrush(Colors.Yellow);
            }
            else if(this.ready == true)
            {
                this.windowsFormsHost.Foreground = this.initialForegroundBrush;
            }
        }

        #endregion
        #region 폰트 패밀리 라디오 버튼 클릭시 처리하기 - fontFamilyRadioButton_Click(sender, e)

        /// <summary>
        /// 폰트 패밀리 라디오 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void fontFamilyRadioButton_Click(object sender, RoutedEventArgs e)
        {
            if(sender == this.timesNewRomanFontFamilyRadioButton)
            {
                this.windowsFormsHost.FontFamily = new FontFamily("Times New Roman");
            }
            else if(sender == this.wingdingsFontFamilyRadioButton)
            {
                this.windowsFormsHost.FontFamily = new FontFamily("Wingdings");
            }
            else if(this.ready == true)
            {
                this.windowsFormsHost.FontFamily = initialFontFamily;
            }
        }

        #endregion
        #region 폰트 크기 라디오 버튼 클릭시 처리하기 - fontSizeRadioButton_Click(sender, e)

        /// <summary>
        /// 폰트 크기 라디오 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void fontSizeRadioButton_Click(object sender, RoutedEventArgs e)
        {
            if(sender == this.tenFontSizeRadioButton)
            {
                this.windowsFormsHost.FontSize = 10;
            }
            else if(sender == this.twelveFontSizeRadioButton)
            {
                this.windowsFormsHost.FontSize = 12;
            }
            else if(this.ready == true)
            {
                this.windowsFormsHost.FontSize = this.initialFontSize;
            }
        }

        #endregion
        #region 폰트 스타일 라디오 버튼 클릭시 처리하기 - fontStyleRadioButton_Click(sender, e)

        /// <summary>
        /// 폰트 스타일 라디오 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void fontStyleRadioButton_Click(object sender, RoutedEventArgs e)
        {
            if(sender == this.italicFontStyleRadioButton)
            {
                this.windowsFormsHost.FontStyle = FontStyles.Italic;
            }
            else if(this.ready == true)
            {
                this.windowsFormsHost.FontStyle = this.initialFontStyle;
            }
        }

        #endregion
        #region 폰트 가중치 라디오 버튼 클릭시 처리하기 - fontWeightRadioButton_Click(sender, e)

        /// <summary>
        /// 폰트 가중치 라디오 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void fontWeightRadioButton_Click(object sender, RoutedEventArgs e)
        {
            if(sender == this.boldFontWeightRadioButton)
            {
                this.windowsFormsHost.FontWeight = FontWeights.Bold;
            }
            else if(this.ready == true)
            {
                this.windowsFormsHost.FontWeight = this.initialFontWeight;
            }
        }

        #endregion
        #region 커스텀 컨트롤 버튼 클릭시 처리하기 - customControl_ButtonClick(sender, e)

        /// <summary>
        /// 커스텀 컨트롤 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void customControl_ButtonClick(object sender, CustomControlEventArgs e)
        {
            this.nameSpan.Inlines.Clear();
            this.addressSpan.Inlines.Clear();
            this.citySpan.Inlines.Clear();
            this.stateSpan.Inlines.Clear();
            this.zipSpan.Inlines.Clear();

            if(e.OKButtonClicked)
            {
                this.nameSpan.Inlines.Add   (" " + e.Name   );
                this.addressSpan.Inlines.Add(" " + e.Address);
                this.citySpan.Inlines.Add   (" " + e.City   );
                this.stateSpan.Inlines.Add  (" " + e.State  );
                this.zipSpan.Inlines.Add    (" " + e.Zip    );
            }
        }

        #endregion
    }
}